<?php

namespace FiloBlu\Storelocator\Controller\Adminhtml\Stores;

use Magento\Backend\App\Action;
use Magento\TestFramework\ErrorLog\Logger;

class RemoveGmb extends \Magento\Backend\App\Action {

    protected $_googleApi;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     */
    public function __construct(Action\Context $context, \FiloBlu\Storelocator\Model\Google\Api $googleApi) {
        $this->_googleApi = $googleApi;
        parent::__construct($context);
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed() {
        return $this->_authorization->isAllowed('FiloBlu_Storelocator::storelocator_delete');
    }

    /**
     * Delete action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute() {
        $id = $this->getRequest()->getParam('store_id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($id) {
            try {
                $model = $this->_objectManager->create('FiloBlu\Storelocator\Model\Stores');
                $model->load($id);
                if ($model->getGmbLocationName()) {

                    $objReturn = $this->_googleApi->deleteLocation($model->getGmbLocationName());

                    if (!is_string($objReturn)) {
                        $this->messageManager->addSuccess(__('StoreID:' . $model->getId() . " deleted from Google My Business"));
                    } else {
                        $this->messageManager->addError(__('Error deleting StoreID:' . $model->getId() . " - Message: " . $objReturn));
                    }
                } else {
                    $this->messageManager->addNotice(__('Error for StoreID:' . $model->getId() . " - Never sent to Google My Business, nothing to do"));
                }

                $model->setGmbLocationName(null);
                $model->save();


                return $resultRedirect->setPath('*/*/edit', ['store_id' => $id]);
            } catch (\Exception $e) {
                $this->messageManager->addError($e->getMessage());
                return $resultRedirect->setPath('*/*/edit', ['store_id' => $id]);
            }
        }
        $this->messageManager->addError(__('We can\'t find a store to update gmb data.'));
        return $resultRedirect->setPath('*/*/edit', ['store_id' => $this->getRequest()->getParam('store_id')]);
    }

}
